import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.53b28f77.js";import{d as m,e3 as b,e4 as f,K as g,b as y,u as n,o as w,Q as k}from"./index.2bd55860.js";import{u as h}from"./workspaceStore.279203c0.js";import"./userStore.826271e3.js";import"./CircularLoading.02011567.js";import"./Logo.3a35c761.js";import"./string.fcee8e82.js";import"./index.fc1b0da7.js";import"./runnerData.578dbe7d.js";import"./url.8ddd701d.js";import"./colorHelpers.4e11e3ec.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8b7170bd-58b8-4735-bbc8-6da3e8fc7d56",e._sentryDebugIdIdentifier="sentry-dbid-8b7170bd-58b8-4735-bbc8-6da3e8fc7d56")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=b(),t=f(),r=h(),_=async()=>{const{redirect:s,...a}=t.query;if(s){await o.push({path:s,query:a,params:t.params});return}o.push({name:"playerHome",query:a})};return(s,a)=>{var c,d,p,u,i;return w(),g("div",v,[y(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const K=k(I,[["__scopeId","data-v-cb33c596"]]);export{K as default};
//# sourceMappingURL=Login.34d852f0.js.map
