import{_ as d}from"./TasksView.vue_vue_type_script_setup_true_lang.0179720a.js";import{L as f}from"./tasksController.a67707d8.js";import{d as p,f as u,c as _,w as t,o as m,b as s,u as o,d6 as y,az as i,bM as b,da as k,Q as w}from"./index.2bd55860.js";import{C as g}from"./ContentLayout.4f819aa5.js";import{a as T}from"./ant-design.52becce9.js";import"./metadata.665ed746.js";import"./PhWebhooksLogo.vue.6d342c2b.js";import"./string.fcee8e82.js";import"./index.093686d2.js";import"./dayjs.b862c5af.js";import"./gateway.79c1aab3.js";import"./popupNotifcation.44e16211.js";import"./linters.5ae2dbb2.js";import"./asyncComputed.8007720a.js";import"./scripts.e3b4956c.js";import"./record.5f72dfbb.js";import"./polling.2addda62.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1e2716d1-8942-4baa-bcb5-ed8c506ff754",e._sentryDebugIdIdentifier="sentry-dbid-1e2716d1-8942-4baa-bcb5-ed8c506ff754")}catch{}})();const x=p({__name:"Tasks",setup(e){const a=new f,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(m(),_(g,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(d,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const $=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{$ as default};
//# sourceMappingURL=Tasks.a4db6551.js.map
