import{O as r}from"./userStore.826271e3.js";import{d as l,J as i,K as u,b as a,w as n,u as o,o as c,az as d,d6 as f,d5 as _}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c3851fb6-5e05-4191-907d-e0290d44802a",e._sentryDebugIdIdentifier="sentry-dbid-c3851fb6-5e05-4191-907d-e0290d44802a")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.51b0c025.js.map
