import{P as a}from"./record.5f72dfbb.js";import{e as r,f as u}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ef47c9f3-6fec-47a5-9ef6-fb23e14ffd6e",e._sentryDebugIdIdentifier="sentry-dbid-ef47c9f3-6fec-47a5-9ef6-fb23e14ffd6e")}catch{}})();const i=new a,b=r("omniChat",()=>{const e=u(!1),t=u(!1),n=()=>{t.value=!0},s=()=>{t.value=!1},f=()=>{e.value=!0,n()},o=()=>{e.value=!1,s()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:s,open:f,close:o,toggle:()=>{e.value?o():f()}}});export{i as o,b as u};
//# sourceMappingURL=omniChatStore.5537d810.js.map
