import{m as a,n,T as r,p as o,P as p,C as d,M as c,s as m,q as s,t as u,v as f,x as g,y}from"./index.2bd55860.js";import{s as l}from"./userStore.826271e3.js";import{_ as w}from"./App.vue_vue_type_style_index_0_lang.0352e290.js";import{a as i}from"./workspaceStore.279203c0.js";import"./PlayerConfigProvider.0a4d05ee.js";import"./colorHelpers.4e11e3ec.js";import"./index.c5fc4b77.js";import"./runnerData.578dbe7d.js";import"./url.8ddd701d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="05e876d1-67c7-4820-a18a-87930400c531",t._sentryDebugIdIdentifier="sentry-dbid-05e876d1-67c7-4820-a18a-87930400c531")}catch{}})();class _{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await l();const t=a(),e=n({render:()=>u(w)});r.init(),o(e,i),_.init(),e.use(i),e.use(t),e.use(p),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",m),s(e,f),s(e,g),s(e,y)})();
//# sourceMappingURL=player.dbe35856.js.map
