import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.0179720a.js";import{R as f}from"./tasksController.a67707d8.js";import{d as _,e4 as b,g,K as y,b as w,w as k,u as n,c as I,F as T,aL as v,o as d,az as B,d6 as j}from"./index.2bd55860.js";import"./gateway.79c1aab3.js";import{a as x,B as C}from"./build.7c1eab74.js";import{a as D}from"./project.2b1fa8f0.js";import"./columns.0eb7599e.js";import{a as R}from"./asyncComputed.8007720a.js";import"./metadata.665ed746.js";import"./PhWebhooksLogo.vue.6d342c2b.js";import"./ant-design.52becce9.js";import"./string.fcee8e82.js";import"./index.093686d2.js";import"./dayjs.b862c5af.js";import"./linters.5ae2dbb2.js";import"./scripts.e3b4956c.js";import"./record.5f72dfbb.js";import"./polling.2addda62.js";import"./popupNotifcation.44e16211.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="649ec922-d29c-43e6-8775-cdbd8fa3d05f",e._sentryDebugIdIdentifier="sentry-dbid-649ec922-d29c-43e6-8775-cdbd8fa3d05f")}catch{}})();const U=_({__name:"Tasks",setup(e){const s=b().params.projectId,l=new f(s),{result:o}=R(async()=>{const r=(await x.list(s)).find(u=>u.latest);if(!r)return null;const[c,p]=await Promise.all([C.get(r.id),D.get(s)]);return{buildSpec:c,project:p}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(d(),y(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(d(),I(m,{key:0,class:"tasks",api:n(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.cc509024.js.map
