import{O as r}from"./userStore.826271e3.js";import{d as l,J as u,K as i,b as a,w as d,u as n,o as c,az as o,d6 as f,d5 as b}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="03c398df-5d6d-495e-95b3-1c4b7228d435",e._sentryDebugIdIdentifier="sentry-dbid-03c398df-5d6d-495e-95b3-1c4b7228d435")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new r().logoutCallback()}),(t,s)=>(c(),i("div",null,[a(n(f),null,{default:d(()=>[o("You're authenticated")]),_:1}),a(n(b),null,{default:d(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.ff1779af.js.map
