import{G as o,dv as s,dw as i}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="9d5dca06-c623-4496-95cd-af62d4fe5044",e._sentryDebugIdIdentifier="sentry-dbid-9d5dca06-c623-4496-95cd-af62d4fe5044")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:d,RangePicker:a}=s(i),y=o(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(d.name,d),e)});export{y as D,r as M,d as Q,a as R,t as W};
//# sourceMappingURL=dayjs.b862c5af.js.map
