import{O as s,R as a}from"./OmniChat.af03f6f5.js";import{d as i,e4 as c,o as d,c as p,u as n}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="940d6c63-77e7-4298-872b-a69d5b24173f",e._sentryDebugIdIdentifier="sentry-dbid-940d6c63-77e7-4298-872b-a69d5b24173f")}catch{}})();const _=i({__name:"ConsoleOmniChat",setup(e){const t=c().params.projectId,r=new a(t);return(u,f)=>(d(),p(s,{"ai-chat-repository":n(r),environment:{origin:"console",projectId:n(t)}},null,8,["ai-chat-repository","environment"]))}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.5f4295e7.js.map
